@@ -76,6 +76,7 @@ will be parsed as the hexadecimal representation of the SHA256 hash of the file
 from __future__ import annotations
 
 import ast
+import builtins
 import itertools
 import inspect
 
@@ -117,51 +118,6 @@ class PythonExpression:
     were present, or a callable which expects keyword arguments corresponding to the
     permitted variable names.
     """
-
-    _ALLOWED_NODE_TYPES = {
-        ast.Add,
-        ast.BinOp,
-        ast.BitAnd,
-        ast.BitAnd,
-        ast.BitOr,
-        ast.BitXor,
-        ast.BoolOp,
-        ast.Compare,
-        ast.Constant,
-        ast.Div,
-        ast.Eq,
-        ast.FloorDiv,
-        ast.Gt,
-        ast.GtE,
-        ast.IfExp,
-        ast.Index,
-        ast.Invert,
-        ast.Is,
-        ast.IsNot,
-        ast.Load,
-        ast.LShift,
-        ast.Lt,
-        ast.LtE,
-        ast.List,
-        ast.MatMult,
-        ast.Mod,
-        ast.Mult,
-        ast.Name,
-        ast.Not,
-        ast.NotEq,
-        ast.Num,
-        ast.Or,
-        ast.Pow,
-        ast.RShift,
-        ast.Slice,
-        ast.Sub,
-        ast.Subscript,
-        ast.Tuple,
-        ast.UAdd,
-        ast.UnaryOp,
-        ast.USub
-    }
-
     def __init__(self, definition: AnyStr, *variables, constants=None, all_variables_allowed=False):
         self.definition = definition
         if not isinstance(definition, str):
@@ -177,14 +133,9 @@ class PythonExpression:
             raise ParserError(F'unknown error parsing the expression: {definition!s}')
         if type(next(nodes)) != ast.Expr:
             raise ParserError(F'not a valid Python expression: {definition!s}')
-        nodes = list(nodes)
-        types = set(type(node) for node in nodes)
-        names = set(node.id for node in nodes if type(node) == ast.Name)
-        if not types <= self._ALLOWED_NODE_TYPES:
-            raise ParserError(
-                'the following operations are not allowed: {}'.format(
-                    ', '.join(t.__name__ for t in types - self._ALLOWED_NODE_TYPES))
-            )
+        names = {node.id for node in nodes if isinstance(node, ast.Name)}
+        names.difference_update(dir(builtins))
+        names.difference_update(globals())
         if not all_variables_allowed and not names <= variables:
             raise ParserVariableMissing(
                 'the following variable names are unknown: {}'.format(
@@ -629,7 +580,7 @@ class DelayedArgument(LazyEvaluation):
         """
         Final modifier `e:expression` or `eval:expression`; uses a `refinery.lib.argformats.PythonExpression`
         parser to process expressions. The expression can contain any meta variable that is attached to the
-        chunk. The `refinery.trivia` unit can be used to attach information such as chunk size and the chunk
+        chunk. The `refinery.cm` unit can be used to attach information such as chunk size and the chunk
         index within the current frame (see `refinery.lib.frame`).
         """
         if not isinstance(expression, str):
