@@ -2,10 +2,10 @@
 # -*- coding: utf-8 -*-
 from Crypto.Cipher import DES3
 
-from . import StandardCipherUnit
+from . import StandardBlockCipherUnit
 
 
-class des3(StandardCipherUnit, cipher=DES3):
+class des3(StandardBlockCipherUnit, cipher=DES3):
     """
     3-DES encryption and decryption.
     """
