@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from .. import arg, Unit, RefineryCriticalException
+from ...lib.argformats import PythonExpression
 
 
 class sorted(Unit):
@@ -9,13 +10,33 @@ class sorted(Unit):
     This unit is a `refinery.nop` on single inputs.
     """
 
-    def __init__(self, length: arg.switch('-l', help='Sort items by length before sorting lexicographically.')):
-        super().__init__(length=length)
+    def __init__(
+        self,
+        key: arg('key', type=str, help='A meta variable expression to sort by instead of sorting the content.') = None,
+        length: arg.switch('-l', help='Sort items by length before sorting lexicographically.') = False
+    ):
+        super().__init__(key=key, length=length)
 
     def filter(self, chunks):
         sortbuffer = []
         invisibles = {}
 
+        if self.args.key is None:
+            if self.args.length:
+                def key(chunk):
+                    return (len(chunk), chunk)
+            else:
+                key = None
+        else:
+            expression = PythonExpression(self.args.key, all_variables_allowed=True)
+            if self.args.length:
+                def key(chunk):
+                    r = expression(**chunk.meta)
+                    return (len(r), r)
+            else:
+                def key(chunk):
+                    return expression(**chunk.meta)
+
         for k, chunk in enumerate(chunks):
             if not chunk.visible:
                 r = k - len(invisibles)
@@ -24,10 +45,7 @@ class sorted(Unit):
             else:
                 sortbuffer.append(chunk)
 
-        if self.args.length:
-            sortbuffer.sort(key=lambda t: (len(t), t))
-        else:
-            sortbuffer.sort()
+        sortbuffer.sort(key=key)
 
         if not invisibles:
             yield from sortbuffer
