@@ -15,7 +15,10 @@ class swap(Unit):
 
     def process(self, data):
         name = self.args.name
-        meta = data.meta[name]
+        try:
+            meta = data.meta[name]
+        except KeyError:
+            meta = bytearray()
         if not isbuffer(meta):
             raise ValueError(F'Unable to swap data with variable {name} because it has type {type(meta).__name__}.')
         return self.labelled(meta, **{name: data})
