@@ -14,7 +14,7 @@ class carve_pe(PathExtractorUnit):
     Executable (PE) file.
     """
     def __init__(
-        self, *paths, list=False, join=False, meta=b'name',
+        self, *paths, list=False, join=False, path=b'name',
         recursive: arg.switch('-r', help='Extract PE files that are contained in already extracted PEs.') = False,
         keep_root: arg.switch('-R', help='If the input chunk is itself a PE, include it as an output chunk.') = False,
         memdump  : arg.switch('-d', help='Use the virtual memory layout of a PE file to calculate its size.') = False,
@@ -24,6 +24,7 @@ class carve_pe(PathExtractorUnit):
             *paths,
             list=list,
             join=join,
+            path=path,
             recursive=recursive,
             keep_root=keep_root,
             memdump=memdump,
@@ -54,7 +55,7 @@ class carve_pe(PathExtractorUnit):
             pedata = mv[offset:offset + pesize]
             info = {}
             if self.args.fileinfo:
-                try: info = pemeta.parse_file_info(pe) or {}
+                try: info = pemeta.parse_version(pe) or {}
                 except Exception: pass
             try:
                 path = info['OriginalFilename']
