@@ -73,18 +73,18 @@ class peek(HexViewer):
         from ...lib.tools import format_size
         from ...lib.magic import magicparse
 
-        if self.args.brief:
-            peeks = []
-        else:
-            peeks = [
-                F'{entropy(memoryview(data)) * 100:05.2f}% entropy',
-                format_size(len(data), align=not self.args.lines)
-            ]
-            magic = magicparse(data)
-            if magic is not None:
-                peeks.append(magic)
+        peeks = []
+        if not self.args.brief:
             if self._idx is not None:
-                peeks.insert(0, F'item {self._idx:02d}')
+                peeks.append(F'item {self._idx:02d}')
+            elif not data and not getattr(data, 'meta', None):
+                return
+            if data:
+                peeks.append(F'{entropy(memoryview(data)) * 100:05.2f}% entropy')
+                peeks.append(format_size(len(data), align=not self.args.lines))
+                magic = magicparse(data)
+                if magic is not None:
+                    peeks.append(magic)
 
         header = ', '.join(peeks)
         dump = None
@@ -143,11 +143,12 @@ class peek(HexViewer):
             return F'--{title}' + '-' * (width - len(title) - 2)
 
         if not self.args.brief:
-            yield separator()
-            if width:
-                yield from textwrap.wrap(header, width + wmod)
-            else:
-                yield header
+            if header:
+                yield separator()
+                if width:
+                    yield from textwrap.wrap(header, width + wmod)
+                else:
+                    yield header
             yield from self._peekmeta(data, width, separator())
 
         if dump:
